# Change log for sphinx-litprog

All notable changes to *sphinx-litprog* will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1] (2019-03-22)

### Fixed

- Fixed wrong document order in literate programming output

## 0.1.0 (2019-03-14)

First public release.

[Unreleased]: https://github.com/torfsen/sphinx-litprog/compare/v0.1.0...master
[0.1.1]: https://github.com/torfsen/sphinx-litprog/compare/v0.1.0...v0.1.1

